<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
# Method: Upgrade
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

$db = $this->GetDb();
$taboptarray = array('mysql' => 'ENGINE=MyISAM');
$dict = NewDataDictionary($db);

switch( $oldversion )
{
	case "1.0":
	case "1.0.1":
		$this->SetPreference('send_notifications_to', get_userid());
		$this->SetPreference('custom_modulename', $this->Lang('friendlyname'));
		$this->SetPreference('admin_section', 'content');

		//current_version: 1.1

	case "1.1":
		$this->CreateEvent('Gbook_entry_deleted');
		$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_gbook_entries", "spamrate I");
		$dict->ExecuteSQLArray($sqlarray);

		//current_version: 1.2
		
	case "1.2":
		if ( $this->GetPreference('send_notifications_to') == '' )
		{
			$send_notifications_to[0] = get_userid();
			$this->SetPreference('send_notifications_to', serialize($send_notifications_to));
		}
		
		//current_version: 2.0.2
		
}

?>